@@ -681,7 +681,7 @@ class Overlay(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
 
     def get_cursor_coords(self, size):
         """Return cursor coords from top_w, if any."""
-        if not hasattr(self.body, 'get_cursor_coords'):
+        if not hasattr(self.top_w, 'get_cursor_coords'):
             return None
         (maxcol, maxrow) = size
         left, right, top, bottom = self.calculate_padding_filler(size,
@@ -1648,7 +1648,7 @@ class Pile(Widget, WidgetContainerMixin, WidgetContainerListContentsMixin):
         focus = focus and self.focus_item == w
         if is_mouse_press(event) and button == 1:
             if w.selectable():
-                self.set_focus_position = i
+                self.focus_position = i
 
         if not hasattr(w, 'mouse_event'):
             return False
