@@ -23,7 +23,6 @@
 Curses-based UI implementation
 """
 
-import sys
 import curses
 import _curses
 
@@ -31,7 +30,7 @@ from urwid import escape
 
 from urwid.display_common import BaseScreen, RealTerminal, AttrSpec, \
     UNPRINTABLE_TRANS_TABLE
-from urwid.compat import bytes, chr2, B, bytes3, PYTHON3
+from urwid.compat import bytes, PYTHON3
 
 KEY_RESIZE = 410 # curses.KEY_RESIZE (sometimes not defined)
 KEY_MOUSE = 409 # curses.KEY_MOUSE
@@ -76,18 +75,18 @@ class Screen(BaseScreen, RealTerminal):
 
     def set_mouse_tracking(self):
         """
-        Enable mouse tracking.  
-        
+        Enable mouse tracking.
+
         After calling this function get_input will include mouse
         click events along with keystrokes.
         """
-        rval = curses.mousemask( 0 
+        curses.mousemask(0
             | curses.BUTTON1_PRESSED | curses.BUTTON1_RELEASED
             | curses.BUTTON2_PRESSED | curses.BUTTON2_RELEASED
             | curses.BUTTON3_PRESSED | curses.BUTTON3_RELEASED
             | curses.BUTTON4_PRESSED | curses.BUTTON4_RELEASED
             | curses.BUTTON_SHIFT | curses.BUTTON_ALT
-            | curses.BUTTON_CTRL )
+            | curses.BUTTON_CTRL)
 
     def start(self):
         """
@@ -249,35 +248,38 @@ class Screen(BaseScreen, RealTerminal):
         If raw_keys is False (default) this function will return a list
         of keys pressed.  If raw_keys is True this function will return
         a ( keys pressed, raw keycodes ) tuple instead.
-        
-        Examples of keys returned
-        -------------------------
-        ASCII printable characters:  " ", "a", "0", "A", "-", "/" 
-        ASCII control characters:  "tab", "enter"
-        Escape sequences:  "up", "page up", "home", "insert", "f1"
-        Key combinations:  "shift f1", "meta a", "ctrl b"
-        Window events:  "window resize"
-        
-        When a narrow encoding is not enabled
-        "Extended ASCII" characters:  "\\xa1", "\\xb2", "\\xfe"
 
-        When a wide encoding is enabled
-        Double-byte characters:  "\\xa1\\xea", "\\xb2\\xd4"
+        Examples of keys returned:
 
-        When utf8 encoding is enabled
-        Unicode characters: u"\\u00a5", u'\\u253c"
+        * ASCII printable characters:  " ", "a", "0", "A", "-", "/"
+        * ASCII control characters:  "tab", "enter"
+        * Escape sequences:  "up", "page up", "home", "insert", "f1"
+        * Key combinations:  "shift f1", "meta a", "ctrl b"
+        * Window events:  "window resize"
 
-        Examples of mouse events returned
-        ---------------------------------
-        Mouse button press: ('mouse press', 1, 15, 13), 
+        When a narrow encoding is not enabled:
+
+        * "Extended ASCII" characters:  "\\xa1", "\\xb2", "\\xfe"
+
+        When a wide encoding is enabled:
+
+        * Double-byte characters:  "\\xa1\\xea", "\\xb2\\xd4"
+
+        When utf8 encoding is enabled:
+
+        * Unicode characters: u"\\u00a5", u'\\u253c"
+
+        Examples of mouse events returned:
+
+        * Mouse button press: ('mouse press', 1, 15, 13),
                             ('meta mouse press', 2, 17, 23)
-        Mouse button release: ('mouse release', 0, 18, 13),
+        * Mouse button release: ('mouse release', 0, 18, 13),
                               ('ctrl mouse release', 0, 17, 23)
         """
         assert self._started
-        
+
         keys, raw = self._get_input( self.max_tenths )
-        
+
         # Avoid pegging CPU at 100% when slowly resizing, and work
         # around a bug with some braindead curses implementations that 
         # return "no key" between "window resize" commands 
