@@ -23,14 +23,16 @@
 from urwid.util import decompose_tagmarkup, get_encoding_mode
 from urwid.canvas import CompositeCanvas, CanvasJoin, TextCanvas, \
     CanvasCombine, SolidCanvas
-from urwid.widget import WidgetMeta, BoxWidget, FlowWidget, FixedWidget, \
+from urwid.widget import WidgetMeta, Widget, BOX, FIXED, FLOW, \
     nocache_widget_render, nocache_widget_render_instance, fixed_size, \
     WidgetWrap, Divider, SolidFill, Text, CENTER, CLIP
 from urwid.container import Pile, Columns
 from urwid.display_common import AttrSpec
-from urwid.decoration import WidgetDecoration, AttrWrap
+from urwid.decoration import WidgetDecoration
+
+class BigText(Widget):
+    _sizing = frozenset([FIXED])
 
-class BigText(FixedWidget):
     def __init__(self, markup, font):
         """
         markup -- same as Text widget markup
@@ -187,8 +189,11 @@ def nocache_bargraph_get_data(self, get_data_fn):
 class BarGraphError(Exception):
     pass
 
-class BarGraph(BoxWidget):
+class BarGraph(Widget):
     __metaclass__ = BarGraphMeta
+
+    _sizing = frozenset([BOX])
+
     ignore_focus = True
 
     eighths = u' ▁▂▃▄▅▆▇'
@@ -199,40 +204,43 @@ class BarGraph(BoxWidget):
         Create a bar graph with the passed display characteristics.
         see set_segment_attributes for a description of the parameters.
         """
-        
+
         self.set_segment_attributes( attlist, hatt, satt )
         self.set_data([], 1, None)
         self.set_bar_width(None)
-        
+
     def set_segment_attributes(self, attlist, hatt=None, satt=None ):
         """
-        attlist -- list containing attribute or (attribute, character)
-            tuple for background, first segment, and optionally
-            following segments. ie. len(attlist) == num segments+1
-            character defaults to ' ' if not specified.
-        hatt -- list containing attributes for horizontal lines. First 
-            lement is for lines on background, second is for lines
-                   on first segment, third is for lines on second segment
-            etc..
-        satt -- dictionary containing attributes for smoothed 
-            transitions of bars in UTF-8 display mode. The values
-            are in the form:
-                (fg,bg) : attr
-            fg and bg are integers where 0 is the graph background,
-            1 is the first segment, 2 is the second, ...  
-            fg > bg in all values.  attr is an attribute with a 
-            foreground corresponding to fg and a background 
-            corresponding to bg.
-            
+        :param attlist: list containing display attribute or
+                        (display attribute, character) tuple for background,
+                        first segment, and optionally following segments.
+                        ie. len(attlist) == num segments+1
+                        character defaults to ' ' if not specified.
+        :param hatt: list containing attributes for horizontal lines. First
+                     element is for lines on background, second is for lines
+                     on first segment, third is for lines on second segment
+                     etc.
+        :param satt: dictionary containing attributes for smoothed
+                     transitions of bars in UTF-8 display mode. The values
+                     are in the form:
+
+                       (fg,bg) : attr
+
+                     fg and bg are integers where 0 is the graph background,
+                     1 is the first segment, 2 is the second, ...
+                     fg > bg in all values.  attr is an attribute with a
+                     foreground corresponding to fg and a background
+                     corresponding to bg.
+
         If satt is not None and the bar graph is being displayed in
         a terminal using the UTF-8 encoding then the character cell
         that is shared between the segments specified will be smoothed
         with using the UTF-8 vertical eighth characters.
-        
+
         eg: set_segment_attributes( ['no', ('unsure',"?"), 'yes'] )
         will use the attribute 'no' for the background (the area from
-        the top of the graph to the top of the bar), question marks 
-        with the attribute 'unsure' will be used for the topmost 
+        the top of the graph to the top of the bar), question marks
+        with the attribute 'unsure' will be used for the topmost
         segment of the bar, and the attribute 'yes' will be used for
         the bottom segment of the bar.
         """
@@ -707,11 +715,12 @@ def calculate_bargraph_display( bardata, top, bar_widths, maxrow ):
     if y_count:
         rowsets.append((y_count, last))
 
-    
     return rowsets
-            
 
-class GraphVScale(BoxWidget):
+
+class GraphVScale(Widget):
+    _sizing = frozenset([BOX])
+
     def __init__(self, labels, top):
         """
         GraphVScale( [(label1 position, label1 markup),...], top )
@@ -775,9 +784,9 @@ class GraphVScale(BoxWidget):
         if maxrow - rows:
             c.pad_trim_top_bottom(0, maxrow - rows)
         return c
-            
-            
-    
+
+
+
 def scale_bar_values( bar, top, maxrow ):
     """
     Return a list of bar values aliased to integer values of maxrow.
@@ -785,21 +794,23 @@ def scale_bar_values( bar, top, maxrow ):
     return [maxrow - int(float(v) * maxrow / top + 0.5) for v in bar]
 
 
-class ProgressBar( FlowWidget ):
+class ProgressBar(Widget):
+    _sizing = frozenset([FLOW])
+
     eighths = u' ▏▎▍▌▋▊▉'
 
     text_align = CENTER
 
     def __init__(self, normal, complete, current=0, done=100, satt=None):
         """
-        normal -- attribute for uncomplete part of progress bar
-        complete -- attribute for complete part of progress bar
-        current -- current progress
-        done -- progress amount at 100%
-        satt -- attribute for smoothed part of bar where the foreground
-            of satt corresponds to the normal part and the
-            background corresponds to the complete part.  If satt
-            is None then no smoothing will be done.
+        :param normal: display attribute for uncomplete part of progress bar
+        :param complete: display attribute for complete part of progress bar
+        :param current: current progress
+        :param done: progress amount at 100%
+        :param satt: display attribute for smoothed part of bar where the
+                     foreground of satt corresponds to the normal part and the
+                     background corresponds to the complete part.  If satt
+                     is ``None`` then no smoothing will be done.
         """
         self.normal = normal
         self.complete = complete
@@ -867,7 +878,9 @@ class ProgressBar( FlowWidget ):
                 (self.normal,maxcol-ccol)]]
         return c
     
-class PythonLogo(FixedWidget):
+class PythonLogo(Widget):
+    _sizing = frozenset([FIXED])
+
     def __init__(self):
         """
         Create canvas containing an ASCII version of the Python
