@@ -19,7 +19,8 @@
 #
 # Urwid web site: http://excess.org/urwid/
 
-from urwid.widget import Text, WidgetWrap, delegate_to_widget_mixin, BOX
+from urwid.widget import (Text, WidgetWrap, delegate_to_widget_mixin, BOX,
+    FLOW)
 from urwid.canvas import CompositeCanvas
 from urwid.signals import connect_signal
 from urwid.container import Columns, Overlay
@@ -28,18 +29,20 @@ from urwid.text_layout import calc_coords
 from urwid.signals import disconnect_signal # doctests
 from urwid.split_repr import python3_repr
 from urwid.decoration import WidgetDecoration
-
+from urwid.command_map import ACTIVATE
 
 class SelectableIcon(Text):
     _selectable = True
     def __init__(self, text, cursor_position=1):
         """
-        text -- markup for this widget
-        cursor_position -- position the cursor will appear in when this
-            widget is in focus
+        :param text: markup for this widget; see :class:`Text` for
+                     description of text markup
+        :param cursor_position: position the cursor will appear in the
+                                text when this widget is in focus
 
-        This is a text widget that is selectable with a cursor
-        displayed at a fixed location in the text when in focus
+        This is a text widget that is selectable.  A cursor
+        displayed at a fixed location in the text when in focus.
+        This widget has no special handling of keyboard or mouse input.
         """
         self.__super.__init__(text)
         self._cursor_position = cursor_position
@@ -66,7 +69,7 @@ class SelectableIcon(Text):
             c = CompositeCanvas(c)
             c.cursor = self.get_cursor_coords(size)
         return c
-    
+
     def get_cursor_coords(self, size):
         """
         Return the position of the cursor if visible.  This method
@@ -79,6 +82,8 @@ class SelectableIcon(Text):
         (maxcol,) = size
         trans = self.get_line_translation(maxcol)
         x, y = calc_coords(self.text, trans, self._cursor_position)
+        if maxcol <= x:
+            return None
         return x, y
 
     def keypress(self, size, key):
@@ -92,7 +97,10 @@ class CheckBoxError(Exception):
     pass
 
 class CheckBox(WidgetWrap):
-    states = { 
+    def sizing(self):
+        return frozenset([FLOW])
+
+    states = {
         True: SelectableIcon("[X]"),
         False: SelectableIcon("[ ]"),
         'mixed': SelectableIcon("[#]") }
@@ -102,30 +110,35 @@ class CheckBox(WidgetWrap):
     # sent when the state of this widget is modified
     # (this variable is picked up by the MetaSignals metaclass)
     signals = ["change"]
-    
+
     def __init__(self, label, state=False, has_mixed=False,
              on_state_change=None, user_data=None):
         """
-        label -- markup for check box label
-        state -- False, True or "mixed"
-        has_mixed -- True if "mixed" is a state to cycle through
-        on_state_change, user_data -- shorthand for connect_signal()
-            function call for a single callback
+        :param label: markup for check box label
+        :param state: False, True or "mixed"
+        :param has_mixed: True if "mixed" is a state to cycle through
+        :param on_state_change: shorthand for connect_signal()
+                                function call for a single callback
+        :param user_data: user_data for on_state_change
+
+        Signals supported: ``'change'``
+
+        Register signal handler with::
+
+          urwid.connect_signal(check_box, 'change', callback, user_data)
 
-        Signals supported: 'change'
-        Register signal handler with:
-          connect_signal(check_box, 'change', callback [,user_data])
         where callback is callback(check_box, new_state [,user_data])
-        Unregister signal handlers with:
-          disconnect_signal(check_box, 'change', callback [,user_data])
+        Unregister signal handlers with::
+
+          urwid.disconnect_signal(check_box, 'change', callback, user_data)
 
         >>> CheckBox(u"Confirm")
-        <CheckBox selectable widget 'Confirm' state=False>
+        <CheckBox selectable flow widget 'Confirm' state=False>
         >>> CheckBox(u"Yogourt", "mixed", True)
-        <CheckBox selectable widget 'Yogourt' state='mixed'>
+        <CheckBox selectable flow widget 'Yogourt' state='mixed'>
         >>> cb = CheckBox(u"Extra onions", True)
         >>> cb
-        <CheckBox selectable widget 'Extra onions' state=True>
+        <CheckBox selectable flow widget 'Extra onions' state=True>
         >>> cb.render((20,), focus=True).text # ... = b in Python 3
         [...'[X] Extra onions    ']
         """
@@ -157,10 +170,10 @@ class CheckBox(WidgetWrap):
 
         >>> cb = CheckBox(u"foo")
         >>> cb
-        <CheckBox selectable widget 'foo' state=False>
+        <CheckBox selectable flow widget 'foo' state=False>
         >>> cb.set_label(('bright_attr', u"bar"))
         >>> cb
-        <CheckBox selectable widget 'bar' state=False>
+        <CheckBox selectable flow widget 'bar' state=False>
         """
         self._label.set_text(label)
         # no need to call self._invalidate(). WidgetWrap takes care of
@@ -173,7 +186,7 @@ class CheckBox(WidgetWrap):
         >>> cb = CheckBox(u"Seriously")
         >>> print cb.get_label()
         Seriously
-        >>> print cb.label  # Urwid 0.9.9 or later
+        >>> print cb.label
         Seriously
         >>> cb.set_label([('bright_attr', u"flashy"), u" normal"])
         >>> print cb.label  #  only text is returned
@@ -188,11 +201,11 @@ class CheckBox(WidgetWrap):
 
         state -- True, False or "mixed"
         do_callback -- False to supress signal from this change
-        
+
         >>> changes = []
-        >>> def callback_a(cb, state, user_data): 
+        >>> def callback_a(cb, state, user_data):
         ...     changes.append("A %r %r" % (state, user_data))
-        >>> def callback_b(cb, state): 
+        >>> def callback_b(cb, state):
         ...     changes.append("B %r" % state)
         >>> cb = CheckBox('test', False, False)
         >>> connect_signal(cb, 'change', callback_a, "user_a")
@@ -201,7 +214,7 @@ class CheckBox(WidgetWrap):
         >>> cb.state
         True
         >>> disconnect_signal(cb, 'change', callback_a, "user_a")
-        >>> cb.state = False  # Urwid 0.9.9 or later
+        >>> cb.state = False
         >>> cb.state
         False
         >>> cb.set_state(True)
@@ -228,15 +241,15 @@ class CheckBox(WidgetWrap):
             ('fixed', self.reserve_columns, self.states[state] ),
             self._label ] )
         self._w.focus_col = 0
-        
+
     def get_state(self):
         """Return the state of the checkbox."""
         return self._state
     state = property(get_state, set_state)
-        
+
     def keypress(self, size, key):
         """
-        Toggle state on 'activate' command.  
+        Toggle state on 'activate' command.
 
         >>> assert CheckBox._command_map[' '] == 'activate'
         >>> assert CheckBox._command_map['enter'] == 'activate'
@@ -251,15 +264,15 @@ class CheckBox(WidgetWrap):
         >>> cb.state
         False
         """
-        if self._command_map[key] != 'activate':
+        if self._command_map[key] != ACTIVATE:
             return key
-        
+
         self.toggle_state()
-        
+
     def toggle_state(self):
         """
         Cycle to the next valid state.
-        
+
         >>> cb = CheckBox("3-state", has_mixed=True)
         >>> cb.state
         False
@@ -286,7 +299,7 @@ class CheckBox(WidgetWrap):
     def mouse_event(self, size, event, button, x, y, focus):
         """
         Toggle state on button 1 press.
-        
+
         >>> size = (20,)
         >>> cb = CheckBox("clickme")
         >>> cb.state
@@ -300,10 +313,10 @@ class CheckBox(WidgetWrap):
             return False
         self.toggle_state()
         return True
-    
-        
+
+
 class RadioButton(CheckBox):
-    states = { 
+    states = {
         True: SelectableIcon("(X)"),
         False: SelectableIcon("( )"),
         'mixed': SelectableIcon("(#)") }
@@ -312,21 +325,26 @@ class RadioButton(CheckBox):
     def __init__(self, group, label, state="first True",
              on_state_change=None, user_data=None):
         """
-        group -- list for radio buttons in same group
-        label -- markup for radio button label
-        state -- False, True, "mixed" or "first True"
-        on_state_change, user_data -- shorthand for connect_signal()
-            function call for a single 'change' callback
+        :param group: list for radio buttons in same group
+        :param label: markup for radio button label
+        :param state: False, True, "mixed" or "first True"
+        :param on_state_change: shorthand for connect_signal()
+                                function call for a single 'change' callback
+        :param user_data: user_data for on_state_change
 
         This function will append the new radio button to group.
         "first True" will set to True if group is empty.
 
-        Signals supported: 'change'
-        Register signal handler with:
-          connect_signal(radio_button, 'change', callback [,user_data])
+        Signals supported: ``'change'``
+
+        Register signal handler with::
+
+          urwid.connect_signal(radio_button, 'change', callback, user_data)
+
         where callback is callback(radio_button, new_state [,user_data])
-        Unregister signal handlers with:
-          disconnect_signal(radio_button, 'change', callback [,user_data])
+        Unregister signal handlers with::
+
+          urwid.disconnect_signal(radio_button, 'change', callback, user_data)
 
         >>> bgroup = [] # button group
         >>> b1 = RadioButton(bgroup, u"Agree")
@@ -334,9 +352,9 @@ class RadioButton(CheckBox):
         >>> len(bgroup)
         2
         >>> b1
-        <RadioButton selectable widget 'Agree' state=True>
+        <RadioButton selectable flow widget 'Agree' state=True>
         >>> b2
-        <RadioButton selectable widget 'Disagree' state=False>
+        <RadioButton selectable flow widget 'Disagree' state=False>
         >>> b2.render((15,), focus=True).text # ... = b in Python 3
         [...'( ) Disagree   ']
         """
@@ -344,17 +362,18 @@ class RadioButton(CheckBox):
             state = not group
 
         self.group = group
-        self.__super.__init__(label, state, False, on_state_change, 
+        self.__super.__init__(label, state, False, on_state_change,
             user_data)
         group.append(self)
-    
 
-    
+
+
     def set_state(self, state, do_callback=True):
         """
         Set the RadioButton state.
 
         state -- True, False or "mixed"
+
         do_callback -- False to supress signal from this change
 
         If state is True all other radio buttons in the same button
@@ -373,10 +392,10 @@ class RadioButton(CheckBox):
         ...     radio_button.set_label(u"Think Harder!")
         >>> connect_signal(b3, 'change', relabel_button)
         >>> b3
-        <RadioButton selectable widget 'Unsure' state=False>
+        <RadioButton selectable flow widget 'Unsure' state=False>
         >>> b3.set_state(True) # this will trigger the callback
         >>> b3
-        <RadioButton selectable widget 'Think Harder!' state=True>
+        <RadioButton selectable flow widget 'Think Harder!' state=True>
         """
         if self._state == state:
             return
@@ -393,12 +412,12 @@ class RadioButton(CheckBox):
             if cb is self: continue
             if cb._state:
                 cb.set_state(False)
-    
-    
+
+
     def toggle_state(self):
         """
         Set state to True.
-        
+
         >>> bgroup = [] # button group
         >>> b1 = RadioButton(bgroup, "Agree")
         >>> b2 = RadioButton(bgroup, "Disagree")
@@ -413,34 +432,41 @@ class RadioButton(CheckBox):
         """
         self.set_state(True)
 
-            
 
 class Button(WidgetWrap):
+    def sizing(self):
+        return frozenset([FLOW])
+
     button_left = Text("<")
     button_right = Text(">")
 
     signals = ["click"]
-    
+
     def __init__(self, label, on_press=None, user_data=None):
         """
-        label -- markup for button label
-        on_press, user_data -- shorthand for connect_signal()
-            function call for a single callback
-        
-        Signals supported: 'click'
-        Register signal handler with:
-          connect_signal(button, 'click', callback [,user_data])
+        :param label: markup for button label
+        :param on_press: shorthand for connect_signal()
+                         function call for a single callback
+        :param user_data: user_data for on_press
+
+        Signals supported: ``'click'``
+
+        Register signal handler with::
+
+          urwid.connect_signal(button, 'click', callback, user_data)
+
         where callback is callback(button [,user_data])
-        Unregister signal handlers with:
-          disconnect_signal(button, 'click', callback [,user_data])
+        Unregister signal handlers with::
+
+          urwid.disconnect_signal(button, 'click', callback, user_data)
 
         >>> Button(u"Ok")
-        <Button selectable widget 'Ok'>
+        <Button selectable flow widget 'Ok'>
         >>> b = Button("Cancel")
         >>> b.render((15,), focus=True).text # ... = b in Python 3
         [...'< Cancel      >']
         """
-        self._label = SelectableIcon("", 0)    
+        self._label = SelectableIcon("", 0)
         cols = Columns([
             ('fixed', 1, self.button_left),
             self._label,
@@ -469,7 +495,7 @@ class Button(WidgetWrap):
         >>> b = Button("Ok")
         >>> b.set_label(u"Yup yup")
         >>> b
-        <Button selectable widget 'Yup yup'>
+        <Button selectable flow widget 'Yup yup'>
         """
         self._label.set_text(label)
 
@@ -480,7 +506,7 @@ class Button(WidgetWrap):
         >>> b = Button(u"Ok")
         >>> print b.get_label()
         Ok
-        >>> print b.label  # Urwid 0.9.9 or later
+        >>> print b.label
         Ok
         """
         return self._label.text
@@ -489,7 +515,7 @@ class Button(WidgetWrap):
     def keypress(self, size, key):
         """
         Send 'click' signal on 'activate' command.
-        
+
         >>> assert Button._command_map[' '] == 'activate'
         >>> assert Button._command_map['enter'] == 'activate'
         >>> size = (15,)
@@ -503,7 +529,7 @@ class Button(WidgetWrap):
         >>> clicked_buttons # ... = u in Python 2
         [...'Cancel', ...'Cancel']
         """
-        if self._command_map[key] != 'activate':
+        if self._command_map[key] != ACTIVATE:
             return key
 
         self._emit('click')
